OC.L10N.register(
    "core",
    {
    "Please select a file." : "Favor de seleccionar un archivo.",
    "File is too big" : "El archivo es demasiado grande.",
    "The selected file is not an image." : "El archivo seleccionado no es una imagen.",
    "The selected file cannot be read." : "El archivo seleccionado no se puede leer.",
    "Invalid file provided" : "Archivo proporcionado inválido",
    "No image or file provided" : "No se especificó un archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "An error occurred. Please contact your admin." : "Se presentó un error. Favor de contactar a su adminsitrador. ",
    "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, favor de intentarlo de nuevo",
    "No crop data provided" : "No se han proporcionado datos del recorte",
    "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
    "Crop is not square" : "El recorte no está cuadrado",
    "State token does not match" : "El token de estado no corresponde",
    "Password reset is disabled" : "Restablecer contraseña se encuentra deshabilitado",
    "Couldn't reset password because the token is invalid" : "No ha sido posible restablecer la contraseña porque el token es inválido",
    "Couldn't reset password because the token is expired" : "No ha sido posible restablecer la contraseña porque el token ha expirado",
    "%s password reset" : "%s restablecer la contraseña",
    "Password reset" : "Restablecer contraseña",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Haga click en el siguiente botón para restablecer su contraseña. Si no ha solicitado restablecer su contraseña, favor de ignorar este correo. ",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Haga click en el siguiente link para restablecer su contraseña. Si no ha solicitado restablecer la contraseña, favor de ignorar este mensaje. ",
    "Reset your password" : "Restablecer su contraseña",
    "Preparing update" : "Preparando actualización",
    "[%d / %d]: %s" : "[%d / %d]: %s ",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Favor de usar el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
    "Turned on maintenance mode" : "Activar modo mantenimiento",
    "Turned off maintenance mode" : "Desactivar modo mantenimiento",
    "Maintenance mode is kept active" : "El modo mantenimiento sigue activo",
    "Updating database schema" : "Actualizando esquema de base de datos",
    "Updated database" : "Base de datos actualizada",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Verificando si el archivo del esquema de base de datos puede ser actualizado (esto puedo tomar mucho tiempo dependiendo del tamaño de la base de datos)",
    "Checked database schema update" : "Actualización del esquema de base de datos verificada",
    "Checking updates of apps" : "Verificando actualizaciónes para aplicaciones",
    "Checking for update of app \"%s\" in appstore" : "Verificando actualizaciones para la aplicacion \"%s\" en la appstore",
    "Update app \"%s\" from appstore" : "Actualizar la aplicación \"%s\" desde la appstore",
    "Checked for update of app \"%s\" in appstore" : "Se verificaron actualizaciones para la aplicación \"%s\" en la appstore",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Verificando si el esquema de la base de datos para %s puede ser actualizado (esto puede tomar mucho tiempo dependiendo del tamaño de la base de datos)",
    "Checked database schema update for apps" : "Se verificó la actualización del esquema de la base de datos para las aplicaciones",
    "Set log level to debug" : "Establecer nivel de bitacora a depurar",
    "Reset log level" : "Restablecer nivel de bitácora",
    "Starting code integrity check" : "Comenzando verificación de integridad del código",
    "Finished code integrity check" : "Verificación de integridad del código terminó",
    "%s (incompatible)" : "%s (incompatible)",
    "Following apps have been disabled: %s" : "Las siguientes aplicaciones han sido deshabilitadas: %s",
    "Already up to date" : "Ya está actualizado",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Su base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente está usando SQLite como el backend de base de datos. Para instalaciones más grandes le recomendamos cambiar a un backend de base de datos diferente.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto es particularmente recomendado cuando se usa el cliente de escritorio para sincronización de archivos. ",
    "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
    "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
    "restricted" : "restringido",
    "invisible" : "invisible",
    "({scope})" : "({scope})",
    "Delete" : "Borrar",
    "Rename" : "Renombrar",
    "Collaborative tags" : "Etiquetas colaborativas",
    "No tags found" : "No se encontraron etiquetas",
    "unknown text" : "texto desconocido",
    "Hello world!" : "¡Hola mundo!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el clima es {weather}",
    "Hello {name}" : "Hola {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de su búsqueda <script>alert(1)</script></strong>",
    "new" : "nuevo",
    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
    "Update to {version}" : "Actualizar a {version}",
    "An error occurred." : "Se presentó un error.",
    "Please reload the page." : "Favor de volver a cargar la página.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulte nuestro comentario  en el foro </a> que cubre este tema. ",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Favor de reportar este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
    "Continue to Nextcloud" : "Continuar a Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["La actualización fue exitosa. Lo estamos redireccionando a Nextcloud en %n segundo. ","La actualización fue exitosa. Lo estamos redireccionando a Nextcloud en %n segundos."],
    "Searching other places" : "Buscando en otras ubicaciones",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados para la búsqueda en otras carpetas para {tag}{filter}{endtag}",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de la búsqueda en otra carpeta","{count} resultados de la búsqueda en otras carpetas"],
    "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
    "Please contact your administrator." : "Favor de contactar al administrador.",
    "An internal error occurred." : "Se presentó un error interno.",
    "Please try again or contact your administrator." : "Favor de volver a intentarlo o contacte a su adminsitrador. ",
    "Username or email" : "Nombre de usuario o contraseña",
    "Password" : "Contraseña",
    "Log in" : "Ingresar",
    "Logging in …" : "Ingresando ...",
    "Wrong username or password." : "Nombre de usuario o contraseña equivocado. ",
    "User disabled" : "Usuario deshabilitado",
    "Reset password" : "Restablecer contraseña",
    "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Favor de contactar a su adminsitrador. ",
    "Password can not be changed. Please contact your administrator." : "Las contraseñas no se pueden cambiar. Favor de contactar a su adminstrador",
    "New password" : "Nueva contraseña",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Cancel" : "Cancelar",
    "Settings" : "Configuraciones ",
    "Search contacts …" : "Buscar contactos ...",
    "No contacts found" : "No se encontraron contactos",
    "Show all contacts …" : "Mostrar todos los contactos ...",
    "Loading your contacts …" : "Cargando sus contactos ... ",
    "Looking for {term} …" : "Buscando {term} ...",
    "No" : "No",
    "Yes" : "Sí",
    "No files in here" : "No hay archivos aquí",
    "New folder" : "Carpeta nueva",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "{newName} already exists" : "{newName} ya existe",
    "Choose" : "Seleccionar",
    "Copy" : "Copiar",
    "Move" : "Mover",
    "Error loading file picker template: {error}" : "Se presentó un error al cargar la plantilla del seleccionador de archivos: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
    "read-only" : "sólo-lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo"],
    "One file conflict" : "Un conflicto en el archivo",
    "New Files" : "Archivos Nuevos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Cuales archivos desea mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si selecciona ambas versiones, se le agregará un número al nombre del archivo copiado.",
    "Continue" : "Continuar",
    "(all selected)" : "(todos seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
    "Pending" : "Pendiente",
    "Saving..." : "Guardando...",
    "Authentication required" : "Se requiere autenticación",
    "This action requires you to confirm your password" : "Esta acción requiere que confirme su contraseña",
    "Confirm" : "Confirmar",
    "Failed to authenticate, try again" : "Falla en la autenticación, favor de reintentar",
    "seconds ago" : "hace segundos",
    "Connection to server lost" : "Se ha perdido la conexión con el servidor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un erorr al cargar la página, recargando en %n segundo","Se presentó un erorr al cargar la página, recargando en %n segundo"],
    "Hide details" : "Ocultar detalles",
    "No action available" : "No hay acciones disponibles",
    "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso denegado",
    "File not found" : "Archivo no encontrado",
    "Error" : "Error",
    "Internal Server Error" : "Error interno del servidor",
    "More details can be found in the server log." : "Puede consultar más detalles en la bitácora del servidor. ",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección Remota: %s",
    "Request ID: %s" : "ID de solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Trace" : "Rastrear",
    "Security warning" : "Advertencia de seguridad",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Storage & database" : "Almacenamiento & base de datos",
    "Data folder" : "Carpeta de datos",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Sólo %s está disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Instale y active módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
    "For more details check out the documentation." : "Favor de consultar la documentación para más detalles. ",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas en la base de datos",
    "Database host" : "Servidor de base de datos",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Favor de especificar el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
    "Performance warning" : "Advertencia de desempeño",
    "Finish setup" : "Terminar configuración",
    "Finishing …" : "Terminando …",
    "Need help?" : "¿Necesita ayuda?",
    "See the documentation" : "Ver la documentación",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Favor de {linkstart}habilitar JavaScript{linkend} y vuelva a cargar la página. ",
    "More apps" : "Más aplicaciones",
    "More" : "Más",
    "Search" : "Buscar",
    "Contacts" : "Contactos",
    "Confirm your password" : "Confirme su contraseña",
    "App token" : "Ficha de la aplicación",
    "Grant access" : "Conceder acceso",
    "Account access" : "Acceso a la cuenta",
    "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
    "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
    "Two-factor authentication" : "Autenticación de dos-factores",
    "Use backup code" : "Usar código de respaldo",
    "Error while validating your second factor" : "Se presentó un error al validar su segundo factor",
    "App update required" : "Se requiere una actualización de la aplicación",
    "These apps will be updated:" : "Las siguientes apllicaciones se actualizarán:",
    "These incompatible apps will be disabled:" : "Las siguientes aplicaciones incompatibles serán deshabilitadas:",
    "The theme %s has been disabled." : "El tema %s ha sido deshabilitado. ",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Favor de asegurarse que la base de datos, la carpeta de configuración y las carpetas de datos hayan sido respaldadas antes de continuar. ",
    "Start update" : "Iniciar actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar que la expiración de tiempo en instalaciones grandes, usted puede ejeuctar el siguiente comando desde su directorio de instalación:",
    "Detailed logs" : "Bitácoras detalladas",
    "Update needed" : "Actualización requerida",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Favor de usar el actualizador desde la línea de comandos ya que su instancia cuenta con más de 50 usuarios.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continuo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
    "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
    "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte a su administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "No fue posible enviar el correo electrónico para restablecer porque no hay una dirección de correo electrónico para este usuario. Favor de contactar a su adminsitrador. ",
    "Couldn't send reset email. Please make sure your username is correct." : "No fue posible restablecer el correo electrónico. Favor de asegurarse que su nombre de usuario sea correcto. ",
    "Dismiss" : "Descartar",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "El link para restablecer su contraseña ha sido enviada a su correo electrónico. Si no lo recibe dentro de un tiempo razonable, verifique las carpetas de spam/basura.<br>Si no la encuentra consulte a su adminstrador local.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sus archivos están encriptados. No habrá manera de recuperar sus datos una vez que restablezca su contraseña. <br />Si no está seguro de qué hacer, favor de contactar a su administrador antes de continuar. <br />¿Realmente desea continuar?",
    "Shared" : "Compartido",
    "Shared by" : "Compartido por",
    "Choose a password for the public link" : "Seleccione una contraseña para el link público",
    "Choose a password for the public link or press the \"Enter\" key" : "Favor de elegir una contraseña para el link público o presione  \"Intro\"",
    "Copied!" : "¡Copiado!",
    "Copy link" : "Copiar enlace",
    "Not supported!" : "¡No está soportado!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "Resharing is not allowed" : "No se permite volver a compartir",
    "Link" : "Link",
    "Hide download" : "Ocultar descarga",
    "Password protect" : "Proteger con contraseña",
    "Allow editing" : "Permitir editar",
    "Email link to person" : "Enviar el link por correo electrónico a una persona",
    "Send" : "Enviar",
    "Allow upload and editing" : "Permitir cargar y editar",
    "Read only" : "Solo lectura",
    "File drop (upload only)" : "Soltar archivo (solo para carga)",
    "Set expiration date" : "Establecer la fecha de expiración",
    "Expiration" : "Expiración",
    "Expiration date" : "Fecha de expiración",
    "Note to recipient" : "Nota al destinatario",
    "Unshare" : "Dejar de compartir",
    "Share to {name}" : "Compartir con {name}",
    "Share link" : "Compartir link",
    "Could not unshare" : "No fue posible dejar de compartir",
    "Shared with you and the group {group} by {owner}" : "Compartido con usted y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con usted por {owner}",
    "Choose a password for the mail share" : "Establecer una contraseña para el elemento compartido por correo",
    "group" : "grupo",
    "remote" : "remoto",
    "email" : "correo electrónico",
    "shared by {sharer}" : "compartido por {sharer}",
    "Can reshare" : "Puede volver a compartir",
    "Can edit" : "Puede editar",
    "Can create" : "Puede crear",
    "Can change" : "Puede cambiar",
    "Can delete" : "Puede borrar",
    "Access control" : "Control de acceso",
    "Error while sharing" : "Se presentó un error al compartir",
    "Share details could not be loaded for this item." : "Los detalles del recurso compartido no se pudieron cargar para este elemento. ",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Se requiere de la menos {count} caracter para el auto completar","Se requieren de la menos {count} caracteres para el auto completar"],
    "This list is maybe truncated - please refine your search term to see more results." : "Esta lista puede estar truncada - favor de refinar sus términos de búsqueda para poder ver más resultados. ",
    "No users or groups found for {search}" : "No se encontraron usuarios o gurpos para {search}",
    "No users found for {search}" : "No se encontraron usuarios para {search}",
    "An error occurred. Please try again" : "Se presentó un error. Favor de volver a intentar",
    "Home" : "Casa",
    "Work" : "Trabajo",
    "Other" : "Otro",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Compartir",
    "Name or email address..." : "Nombre o dirección de correo electrónico",
    "Name or federated cloud ID..." : "Nombre o ID de nube federada...",
    "Name, federated cloud ID or email address..." : "Nombre, ID de nube federada o dirección de correo electrónico...",
    "Name..." : "Nombre...",
    "Error removing share" : "Se presentó un error al dejar de compartir",
    "SQLite will be used as database." : "SQLite será usado como la base de datos.",
    "For larger installations we recommend to choose a different database backend." : "Para instalaciones más grandes le recomendamos elegir un backend de base de datos diferente.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLiite es especialmente desalentado al usar el cliente de escritorio para sincrionizar. ",
    "Wrong password." : "Contraseña inválida. ",
    "New Password" : "Nueva Contraseña",
    "Cancel log in" : "Cancelar inicio de sesión"
},
"nplurals=2; plural=(n != 1);");
